Learn R Programming

DrugVsDisease (version 2.12.0)

customDB: Custom Gene Expression Profiles

Description

Matrix containing a set of ranked gene expression profiles which can be used as custom input into classifyprofiles.

Usage

data(customDB)

Arguments

source

http://www.broadinstitute.org/cmap/{http://www.broadinstitute.org/cmap/}

Details

This is an example subset of the drugRL available in the DrugVsDiseasedata package DrugVsDiseasedata, data object drugRL, based on data from the Connectivity Map

Examples

Run this code
data(customDB)
## maybe str(profiles) ; plot(profiles) ...

Run the code above in your browser using DataLab