Learn R Programming

DrugVsDisease (version 2.12.0)

customedge: Edge attributes for example custom network

Description

Data frame containing the required format of an edge attribute file input into Cytoscape

Usage

data(customedge)

Arguments

source

http://www.broadinstitute.org/cmap/{http://www.broadinstitute.org/cmap/}

Details

Example subset of edge attributes taken from the full reference data set of drug compounds in the DvDdata package.

Examples

Run this code
data(customedge)

Run the code above in your browser using DataLab