Learn R Programming

DrugVsDisease (version 2.12.0)

customsif: SIF file for custom clusters

Description

Data frame containing SIF format file of a network which could be input into the classifyprofile function.

Usage

data(customsif)

Arguments

source

http://www.broadinstitute.org/cmap/{http://www.broadinstitute.org/cmap/}

Details

Example subset of edge attributes taken from the full reference data set of drug compounds in the DvDdata package.

Examples

Run this code
data(customsif)

Run the code above in your browser using DataLab