Learn R Programming

DrugVsDisease (version 2.12.0)

profiles: Gene Expression Profiles

Description

List containing ranked lists of gene expression and associated p-values for a set of profiles.

Usage

data(profiles)

Arguments

Format

List containing rank of differential gene expression and pvalues in a list. Each item in the list contains a matrix. Matrix has number of rows equal number genes and columns for the different profiles.

Examples

Run this code
data(profiles)
## maybe str(profiles) ; plot(profiles) ...

Run the code above in your browser using DataLab