Learn R Programming

DrugVsDisease (version 2.12.0)

selectrankedlists: Select Ranked Lists

Description

Given a list with two elements, one containing ranklists for a set of regression models and the second containing the associated p-values. This function is used to extract a subset of the models.

Usage

selectrankedlists(ranklist, colsinc)

Arguments

ranklist
List with two elements (as output from generate profiles): Ranklist: Matrix containing the ranks of gene expression. Rows containing the genes, columns the different profiles.

Pvalues: Matrix containing the associated p-values to the differential expression profiles in Ranklist.

colsinc
Vector of integers containing the column references of the profiles to select.

Value

Ranklist
Matrix containing the ranks of gene expression. Rows containing the genes, columns the selected profiles
Pvalues
Matrix containing the associated p-values to the differential expression profiles in Ranklist

Details

Format of list provided to selectrankedlists is the same as is output from generateprofiles generateprofiles. The output from selectrankedlists can be used as input to the classify profile function classifyprofile.

See Also

generateprofiles, classifyprofile.

Examples

Run this code
data(profiles)
selectprofile<-selectrankedlists(profiles,1)
classification<-classifyprofile(data=selectprofile$ranklist,noperm=10,signif.fdr=1)

Run the code above in your browser using DataLab