Learn R Programming

DrugVsDisease (version 2.12.0)

selprofile: List: Differential gene expression and p-values

Description

Ranklist which has the rank of each gene according to differential expression. P-values is the second element in the list containing the associated p-value for gene differential expression.

Usage

data(selprofile)

Arguments

Format

List with two elements, the first ranklist containing the ranked position of the gene according to its differential expression. The second item in the list is the associated pvalues.

Details

Example ranked list of differential expression. Taken from Array express experiment E-GEOD-22528

Examples

Run this code
data(selprofile)

## maybe str(selprofile) ; plot(selprofile) ...

Run the code above in your browser using DataLab