customClust: Custom Clusters
Description
Matrix containing a set of drugs and their corresponding clusters which can be used as input to the classifyprofile function.format
Data frame with 47 rows and 2 columns. Columns are headed "Drug" and "Cluster".source
http://www.broadinstitute.org/cmap/{http://www.broadinstitute.org/cmap/}Details
Each row refers to a compound in the customDB data set
link{customDB} with its corresponding cluster assignment in the
second column. These profiles are a subset of the Connectivity Map data
[1] (full set available in the DrugVsDiseasedata package
DrugVsDiseasedata, data object drugRL, for example use. Clusters
were generated using affinity propagation clustering [2]References
[1] Lamb J et~al. (2006) The Connectivity Map: Using Gene-Expression Signatures to Connect Small Molecules, Genes, and Disease. Science, 313(5795), 1929-1935.
[2] U. Bodenhofer, A. Kothmeier, and S. Hochreiter. APCluster: an R package for affinity propagation clustering. Bioinformatics, 27(17):2463-2464, 2011.