customedge: Edge attributes for example custom network
Description
Data frame containing the required format of an edge attribute file input into Cytoscapesource
http://www.broadinstitute.org/cmap/{http://www.broadinstitute.org/cmap/}Details
Example subset of edge attributes taken from the full reference data set of drug compounds in the DvDdata package.