customsif: SIF file for custom clusters
Description
Data frame containing SIF format file of a network which could be input into the classifyprofile function.source
http://www.broadinstitute.org/cmap/{http://www.broadinstitute.org/cmap/}Details
Example subset of edge attributes taken from the full reference data set of drug compounds in the DvDdata package.