List containing ranked lists of gene expression and associated p-values for a set of profiles.
Usage
data(profiles)
Arguments
Format
List containing rank of differential gene expression and pvalues in a list. Each item in the list contains a matrix. Matrix has number of rows equal number genes and columns for the different profiles.